@@ -77,13 +77,27 @@ class Dialog:
             log.debug(f"Challenge failed: {self}")
             return
         except StopAsyncIteration:
-            log.debug(f"Closing: {self}")
-            self.session.close()
+            await self._close()
             raise
         else:
             log.debug(f"Sending: {self.campaign.challenge}")
             await self.campaign.challenge.send(bot=self.bot, entity=self.entity)
 
+    async def stop(self) -> None:
+        """
+        Suddenly stop a dialog, and cleanup.
+        """
+        log.debug(f"Stopping: {self}")
+        await self.campaign.adventure.aclose()
+        await self._close()
+
+    async def _close(self) -> None:
+        """
+        Close and cleanup a dialog.
+        """
+        log.debug(f"Closing: {self}")
+        self.session.close()
+
     async def __message(self, msg, **kwargs) -> telethon.types.Message:
         """
         Send a Telegram message to the user at the other side of the dialog.
@@ -99,6 +113,7 @@ class Dialog:
             parse_mode="HTML",
             message=msg,
             buttons=self.bot.build_reply_markup(telethon.tl.custom.Button.clear()),
+            link_preview=False,
             **kwargs
         )
 
@@ -111,6 +126,9 @@ class Dialog:
             if text.startswith("/whois"):
                 yield self.__whois()
 
+            elif text.startswith("/help"):
+                yield self.__help()
+
             elif text.startswith("/start"):
                 if msg.is_private:
                     yield self.__start()
@@ -119,14 +137,49 @@ class Dialog:
                         f"⚠️ Questo comando funziona solo in chat privata (@{os.environ['TELEGRAM_BOT_USERNAME']})."
                     )
 
-            elif text.startswith("/privacy"):
+            elif text.startswith("/settings"):
                 if msg.is_private:
-                    yield self.__privacy()
+                    yield self.__settings()
                 else:
                     await self.__message(
                         f"⚠️ Questo comando funziona solo in chat privata (@{os.environ['TELEGRAM_BOT_USERNAME']})."
                     )
 
+    async def __help(self) -> AsyncAdventure:
+        """The /help command."""
+        msg: telethon.tl.custom.Message = yield
+
+        lines = [
+            f"ℹ️ @{os.environ['TELEGRAM_BOT_USERNAME']} è il bot-moderatore del gruppo studentesco Unimore "
+            f"Informatica.",
+            "",
+            'Controlla che gli account che si uniscono al gruppo siano effettivamente studenti verificandone '
+            'l\'identità attraverso autenticazione '
+            '<a href="https://en.wikipedia.org/wiki/OpenID_Connect">OpenID Connect</a> con il loro account Google '
+            'Apps for Education.',
+            "",
+            "<b>Comandi disponibili:</b>",
+            "- /help | Ottieni informazioni sul bot",
+            "- /whois | Visualizza informazioni su uno studente o un account",
+        ]
+
+        if msg.is_private:
+            lines = [
+                *lines,
+                "- /start | Avvia il processo di autenticazione",
+                "- /settings | Cambia le tue impostazioni di privacy",
+            ]
+        else:
+            lines = [
+                *lines,
+                "",
+                "<i>Più comandi sono disponibili avviando una chat privata con il bot!</i>",
+            ]
+
+        await self.__message(
+            "\n".join(lines)
+        )
+
     async def __start(self) -> AsyncAdventure:
         """Disambiguation for the /start command."""
         msg: telethon.tl.custom.Message = yield
@@ -211,7 +264,7 @@ class Dialog:
             message="📝 Vuoi permettere agli altri studenti verificati di visualizzare il tuo <b>vero nome</b> e la tua "
                     "<b>email istituzionale</b> attraverso il comando /whois?\n\n"
                     "(Gli amministratori del gruppo vi avranno comunque accesso, e potrai cambiare idea in qualsiasi "
-                    "momento con il comando /privacy.)",
+                    "momento con il comando /settings.)",
             choices=[["👤 Nascondi.", "📱 Mostra!"]]
         )
         st.privacy = choice.message == "👤 Nascondi."
@@ -236,8 +289,8 @@ class Dialog:
         )
         return
 
-    async def __privacy(self) -> AsyncAdventure:
-        """The /privacy command, used to toggle between privacy states."""
+    async def __settings(self) -> AsyncAdventure:
+        """The /settings command, used to toggle between privacy states."""
         msg: telethon.tl.custom.Message = yield
 
         from_user = await msg.get_sender()
@@ -256,7 +309,7 @@ class Dialog:
             message="📝 Vuoi permettere agli altri studenti verificati di visualizzare il tuo <b>vero nome</b> e la tua "
                     "<b>email istituzionale</b> attraverso il comando /whois?\n\n"
                     "(Gli amministratori del gruppo vi avranno comunque accesso, e potrai cambiare idea in qualsiasi "
-                    "momento con il comando /privacy.)",
+                    "momento con il comando /settings.)",
             choices=[["👤 Nascondi.", "📱 Mostra!"]],
         )
         tg.st.privacy = choice.message == "👤 Nascondi."
